# ammaritproj

`ammaritproj` is a package that can tell the **area**, **perimeter**, **type by side**, of any triangle.
It is designed mainly for learning purposes and as an example of Python packaging.

---

## Features
- **Area of Triange**: use a function `Area(a,b,c)` to find area of any triangle
- **Perimeter of Triangle**: use a function `Perimeter(a,b,c)` to find perimeter of any triangle
- **Type_by_Side**: use a function `Type_by_Side(a,b,c)` to identify the type of triangle by side.

---

## Installation

You can install the package directly from PyPI:

```
pip install ammaritproj

```